import * as React from 'react';
import { InterestRateContractTemplate } from '@jdxconsulting/cdm-model';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
export var TradeEntryFMode;
(function (TradeEntryFMode) {
    TradeEntryFMode[TradeEntryFMode["CounterParty"] = 1] = "CounterParty";
    TradeEntryFMode[TradeEntryFMode["ETF"] = 2] = "ETF";
})(TradeEntryFMode || (TradeEntryFMode = {}));
export var TradeEntryF = function (props) {
    var filteredCounterPartyList = function (unfilteredList, excludeLegalEntityIds) {
        return unfilteredList.filter(function (m) {
            return excludeLegalEntityIds.find(function (e) { return e === m.state.data.membershipMetadata.legalEntityId; }) === undefined;
        });
    };
    var getCounterPartyNameFromLEI = function (legalEntityId) {
        var foundMember = props.facingOptions.find(function (m) { return m.state.data.membershipMetadata.legalEntityId === legalEntityId; });
        if (foundMember) {
            return foundMember.state.data.membershipMetadata.name;
        }
        throw new Error("Could not find Member for Legal Entity Id: " + legalEntityId);
    };
    var _a = React.useState(filteredCounterPartyList(props.facingOptions, [props.originator.state.data.membershipMetadata.legalEntityId])), cp1List = _a[0], setCP1List = _a[1];
    var _b = React.useState(filteredCounterPartyList(props.facingOptions, [props.originator.state.data.membershipMetadata.legalEntityId])), cp2List = _b[0], setCP2List = _b[1];
    var _c = React.useState("USD"), ccyState = _c[0], setCCY = _c[1];
    var _d = React.useState(100000), valueState = _d[0], setValue = _d[1];
    var _e = React.useState("M"), periodState = _e[0], setPeriod = _e[1];
    var _f = React.useState(props.originator.state.data.membershipMetadata.legalEntityId), cp1State = _f[0], setCP1 = _f[1];
    var _g = React.useState(props.facingOptions.filter(function (m) {
        return m.state.data.membershipMetadata.name.toUpperCase() !== "BNO" &&
            m.state.data.membershipMetadata.role.toUpperCase() !== "CCP" &&
            m.state.data.membershipMetadata.legalEntityId !== props.originator.state.data.membershipMetadata.legalEntityId;
    })[0].state.data.membershipMetadata.legalEntityId), cp2State = _g[0], setCP2 = _g[1];
    var submitData = function () {
        var data = InterestRateContractTemplate;
        data.account[0].accountNumber = cp1State;
        data.account[1].accountNumber = cp2State;
        data.contractualProduct.economicTerms.payout.interestRatePayout[0].payerReceiver.payerPartyReference = getCounterPartyNameFromLEI(cp1State);
        data.contractualProduct.economicTerms.payout.interestRatePayout[0].payerReceiver.receiverPartyReference = getCounterPartyNameFromLEI(cp2State);
        data.contractIdentifier[0].version = 1;
        data.contractIdentifier[0].identifierValue.identifier = "TradeId_" + new Date().getTime();
        data.contractualProduct.economicTerms.payout.interestRatePayout[0].calculationPeriodDates.calculationPeriodFrequency.period = periodState;
        data.contractualProduct.economicTerms.payout.interestRatePayout[0].quantity.notionalSchedule.notionalStepSchedule.currency = ccyState;
        data.contractualProduct.economicTerms.payout.interestRatePayout[0].quantity.notionalSchedule.notionalStepSchedule.initialValue = valueState;
        data.tradeDate.adjustableDate.unadjustedDate = new Date().toISOString().split('T')[0];
        return data;
    };
    var cp1Changed = function (event) {
        console.log("*** NEW TRADE *** CP1 changed to " + event.target.value);
        // Reconcile dependent CP2 selector ....
        setCP2List(filteredCounterPartyList(props.facingOptions, [event.target.value]));
        setCP1(event.target.value);
    };
    var cp2Changed = function (event) {
        console.log("*** NEW TRADE *** CP2 changed to " + event.target.value);
        // Reconcile dependent CP1 selector ....
        setCP1List(filteredCounterPartyList(props.facingOptions, [event.target.value]));
        setCP2(event.target.value);
    };
    var periodChanged = function (event) {
        console.log("*** NEW TRADE *** Period changed to " + event.target.value);
        setPeriod(event.target.value);
    };
    var ccyChanged = function (event) {
        console.log("*** NEW TRADE *** CCY changed to " + event.target.value);
        setCCY(event.target.value);
    };
    var valueChanged = function (event) {
        console.log("*** NEW TRADE *** Value changed to " + event.target.value);
        setValue(event.target.value);
    };
    return (React.createElement("div", null,
        React.createElement("h1", null, "Trade Entry"),
        React.createElement("table", { className: "table table-striped table-hover" },
            React.createElement("thead", null,
                React.createElement("tr", null,
                    props.mode === TradeEntryFMode.CounterParty ? React.createElement("th", null, "Originator") : React.createElement("th", null, "CP 1"),
                    props.mode === TradeEntryFMode.CounterParty ? React.createElement("th", null, "Facing") : React.createElement("th", null, "CP 2"),
                    React.createElement("th", null, "CCY"),
                    React.createElement("th", null, "Value"),
                    React.createElement("th", null, "Payment Period"),
                    React.createElement("th", null))),
            React.createElement("tbody", null,
                React.createElement("tr", null,
                    props.mode === TradeEntryFMode.CounterParty ?
                        React.createElement("td", null, props.originator.state.data.membershipMetadata.name) :
                        React.createElement("td", null,
                            React.createElement("select", { className: "custom-select", onLoad: cp1Changed, onChange: cp1Changed }, cp1List.map(function (fo) {
                                return React.createElement("option", { value: fo.state.data.membershipMetadata.partyId, key: fo.state.data.membershipMetadata.partyId }, fo.state.data.membershipMetadata.name);
                            }))),
                    React.createElement("td", null,
                        React.createElement("select", { className: "custom-select", onLoad: cp2Changed, onChange: cp2Changed }, cp2List.map(function (fo) {
                            return React.createElement("option", { value: fo.state.data.membershipMetadata.partyId, key: fo.state.data.membershipMetadata.partyId }, fo.state.data.membershipMetadata.name);
                        }))),
                    React.createElement("td", null,
                        React.createElement("select", { className: "custom-select", onChange: ccyChanged },
                            React.createElement("option", { value: "USD", key: "USD" }, "USD"),
                            React.createElement("option", { value: "GBP", key: "GBP" }, "GBP"),
                            React.createElement("option", { value: "EUR", key: "EUR" }, "EUR"))),
                    React.createElement("td", null,
                        React.createElement("input", { type: "text", name: "tradeValue", defaultValue: valueState.toString(), onChange: valueChanged })),
                    React.createElement("td", null,
                        React.createElement("select", { className: "custom-select", onChange: periodChanged },
                            React.createElement("option", { value: "M", key: "M" }, "Monthly"),
                            React.createElement("option", { value: "W", key: "W" }, "Weekly"),
                            React.createElement("option", { value: "D", key: "D" }, "Daily"))),
                    React.createElement("td", null,
                        React.createElement("button", { type: "button", className: "btn btn-info", title: "Submit New Trade.", onClick: function () { console.log("*** NEW TRADE *** " + JSON.stringify(submitData())); props.submitHandler(props.originator.host.hostIP, props.originator.host.hostPort, JSON.stringify(submitData())); } },
                            React.createElement(FontAwesomeIcon, { icon: "sign-in-alt" }))))))));
};
//# sourceMappingURL=tradeEntryF.js.map