import * as signalR from "@aspnet/signalr";
import { Store } from '../../../../../src/index';
import * as Actions from '../actions/tradeList';
import { NewLogEntry } from "@jdxconsulting/cdm-ux-common/lib/cdm-logger/model/logEntry";
import { PaymentReceivedAction } from "../actions/payment";
export var InitPaymentListenerPromise = function (host, port) {
    return new Promise(function (response, reject) {
        var connection = new signalR.HubConnectionBuilder()
            .withUrl("http://" + host + ":" + port + "/paymenthub")
            .configureLogging(signalR.LogLevel.Information)
            .build();
        connection.start().then(function () {
            console.log("Connected to real-time payment hub. Host: " + host + ". Port: " + port + ".");
            NewLogEntry(Store, "Connected to real-time payment hub. Host: " + host + ". Port: " + port + ".", false, 10);
            connection.send("newMessage", Store.getState().CurrentMember.state.data.membershipMetadata.partyId, "Connect Me").catch(function (err) { return console.error(err); });
            connection.on("newPayment", function (payment) {
                console.log("NEW: " + payment);
                var newPayment = JSON.parse(payment);
                NewLogEntry(Store, "New Payment Notification Received. Id: " + newPayment.contractId, false, 10);
                Store.dispatch(PaymentReceivedAction(newPayment));
            });
        }).catch(function (err) { console.error(err); reject(err); });
    });
};
export var InitTradeListenerPromise = function (host, port) {
    return new Promise(function (response, reject) {
        var connection = new signalR.HubConnectionBuilder()
            .withUrl("http://" + host + ":" + port + "/tradehub")
            .configureLogging(signalR.LogLevel.Information)
            .build();
        connection.start().then(function () {
            console.log("Connected to real-time trade hub. Host: " + host + ". Port: " + port + ".");
            NewLogEntry(Store, "Connected to real-time trade hub. Host: " + host + ". Port: " + port + ".", false, 10);
            connection.send("newMessage", Store.getState().CurrentMember.state.data.membershipMetadata.partyId, "Connect Me").catch(function (err) { return console.error(err); });
            connection.on("newTrade", function (trade) {
                console.log("NEW: " + trade);
                var newTrade = JSON.parse(trade);
                NewLogEntry(Store, "New Trade Notification Received. Id: " + newTrade.cdmContract.contractIdentifier[0].identifierValue.identifier + ". Status: " + newTrade.contractStatus, false, 10);
                Store.dispatch(Actions.NewRTTrade(newTrade));
                setTimeout(function () { return Store.dispatch(Actions.ClearTradeHighlight(newTrade)); }, 10000);
            });
            connection.on("updateTrade", function (trade) {
                console.log("UPDATE: " + trade);
                var updateTrade = JSON.parse(trade);
                NewLogEntry(Store, "Amended Trade Notification Received. Id: " + updateTrade.cdmContract.contractIdentifier[0].identifierValue.identifier + ". Status: " + updateTrade.contractStatus, false, 10);
                Store.dispatch(Actions.UpdateTrade(updateTrade));
                setTimeout(function () { return Store.dispatch(Actions.ClearTradeHighlight(updateTrade)); }, 10000);
            });
            connection.on("deleteTrade", function (trade) {
                console.log("DELETE: " + trade);
                var deleteTrade = JSON.parse(trade);
                NewLogEntry(Store, "Deleted Trade Notification Received. Id: " + deleteTrade.cdmContract.contractIdentifier[0].identifierValue.identifier + ". Status: " + deleteTrade.contractStatus, false, 10);
                Store.dispatch(Actions.RemoveTrade(deleteTrade));
                setTimeout(function () { return Store.dispatch(Actions.ClearTradeHighlight(deleteTrade)); }, 10000);
            });
            connection.on("messageReceived", function (user, message) {
                console.log(user + ' - ' + message);
            });
            response("*Promise* Connected to real-time trade hub. Host: " + host + ". Port: " + port + ".");
        }).catch(function (err) { console.error(err); reject(err); });
    });
};
//# sourceMappingURL=realTime.js.map