var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import axios from 'axios';
import { Store } from '../../../../../src/index';
import * as Actions from '../actions/tradeList';
import { LogErrorAction } from '@jdxconsulting/cdm-ux-common/lib/cdm-logger/actions/logError';
import { NewLogEntry } from '@jdxconsulting/cdm-ux-common/lib/cdm-logger/model/logEntry';
import { NewError } from '@jdxconsulting/cdm-ux-common/lib/cdm-logger/model/error';
import { HistoryState } from '@jdxconsulting/cdm-ux-common/lib/cdm-navigation/model/history';
import { PaymentReceivedAction, ClearPaymentsAction } from '../actions/payment';
export var GetTradesPromise = function (host, port) {
    return new Promise(function (response, reject) {
        console.log('http://' + host + ':' + port + '/api/memberApi/allCDMContracts');
        axios.get('http://' + host + ':' + port + '/api/memberApi/allCDMContracts')
            .then(function (response1) {
            Store.dispatch(Actions.ClearTrades());
            Store.dispatch(ClearPaymentsAction());
            var tradeList = response1.data;
            tradeList.forEach(function (trade) {
                Store.dispatch(Actions.NewRPCTrade(trade));
                GetPayments(host, port, trade.cdmContract.contractIdentifier[0].identifierValue.identifier);
            });
            NewLogEntry(Store, tradeList.length + " Trades Loaded for " + Store.getState().CurrentMember.state.data.membershipMetadata.name, false, 10);
            response("*Promise* " + tradeList.length + " Trades Loaded for " + Store.getState().CurrentMember.state.data.membershipMetadata.name);
        }).catch(function (error) {
            // handle error
            console.error(error.response.data);
            Store.dispatch(LogErrorAction(error));
            // NewError(Store, (error.response.data) ? error.response.data : error);
            reject(error);
        }).then(function () {
            // always executed	
        });
    });
};
export var GetTradesLineage = function (host, port, trade) {
    var params;
    var lineageList = [];
    if (trade.contractStatus === 'TERMINATED' || trade.contractStatus === 'NOVATED') {
        params = {
            params: {
                contractId: trade.cdmContract.contractIdentifier[0].identifierValue.identifier,
                contractIdScheme: trade.cdmContract.contractIdentifier[0].identifierValue.identifierScheme,
                contractState: trade.contractStatus
            }
        };
    }
    else {
        params = {
            params: {
                contractId: trade.cdmContract.contractIdentifier[0].identifierValue.identifier,
                contractIdScheme: trade.cdmContract.contractIdentifier[0].identifierValue.identifierScheme
            }
        };
    }
    if (params && trade.contractStatus !== 'DRAFT') {
        console.log('http://' + host + ':' + port + '/api/memberApi/CDMContractParents');
        axios.get('http://' + host + ':' + port + '/api/memberApi/CDMContractParents', params)
            .then(function (response) {
            var tradeLineageList = response.data;
            tradeLineageList.forEach(function (tradeLineage) {
                var fakeIRCWS = {
                    cdmContract: tradeLineage,
                    contractStatus: trade.cdmContract.contractIdentifier[0].identifierValue.identifier
                };
                var lineageChildrenList = GetTradesLineage(host, port, fakeIRCWS);
                if (lineageChildrenList) {
                    fakeIRCWS.cdmContractsLineage = lineageChildrenList;
                }
                lineageList.push(fakeIRCWS);
            });
        }).catch(function (error) {
            // handle error
            console.error(error.response.data);
            NewError(Store, (error.response.data) ? error.response.data : error);
        }).then(function () {
            // always executed	
        });
    }
    return lineageList;
};
export var PersistDraftCDMContract = function (host, port, eventJSON) {
    console.log('http://' + host + ':' + port + '/api/memberApi/persistDraftCDMContract');
    axios.post('http://' + host + ':' + port + '/api/memberApi/persistDraftCDMContract', eventJSON)
        .then(function (response) {
        console.log(response);
        NewLogEntry(Store, 'Register Draft Trade. ' + response.data, false, 10);
        HistoryState.push("/trades/");
    })
        .catch(function (error) {
        // handle error
        console.error(error.response.data);
        NewError(Store, (error.response.data) ? error.response.data : error);
    })
        .then(function () {
        // always executed
    });
};
export var RequestCompressActiveContracts = function (host, port, tradeIdList) {
    console.log('http://' + host + ':' + port + '/api/memberApi/compressCDMContracts');
    var data = { contractsToCompress: [] };
    tradeIdList.forEach(function (tid) {
        data.contractsToCompress.push({ contractId: tid, contractIdScheme: 'http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/' });
    });
    axios.post('http://' + host + ':' + port + '/api/memberApi/compressCDMContracts', data)
        .then(function (response) {
        console.log(response);
        NewLogEntry(Store, 'Compress Trades. ' + response.data, false, 10);
    })
        .catch(function (error) {
        // handle error
        console.error(error.response.data);
        NewError(Store, (error.response.data) ? error.response.data : error);
    })
        .then(function () {
        // always executed
    });
};
export var RequestApproveDraftCDMContract = function (host, port, tradeIdList) {
    console.log('http://' + host + ':' + port + '/api/memberApi/approveDraftCDMContract');
    tradeIdList.forEach(function (tid) {
        var data = { contractId: tid, contractIdScheme: 'http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/' };
        axios.post('http://' + host + ':' + port + '/api/memberApi/approveDraftCDMContract', data)
            .then(function (response) {
            console.log(response);
            NewLogEntry(Store, 'Approve Draft Trade(s). ' + response.data, false, 10);
        })
            .catch(function (error) {
            // handle error
            console.error(error.response.data);
            NewError(Store, (error.response.data) ? error.response.data : error);
        })
            .then(function () {
            // always executed
        });
    });
};
export var RequestRejectDraftCDMContract = function (host, port, tradeIdList) {
    console.log('http://' + host + ':' + port + '/api/memberApi/rejectDraftCDMContract');
    tradeIdList.forEach(function (tid) {
        var data = { contractId: tid, contractIdScheme: 'http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/' };
        // TODO Chage Endpoint
        axios.post('http://' + host + ':' + port + '/api/memberApi/rejectDraftCDMContract', data)
            .then(function (response) {
            console.log(response);
            NewLogEntry(Store, 'Reject Draft Trade(s). ' + response.data, false, 10);
        })
            .catch(function (error) {
            // handle error
            console.error(error.response.data);
            NewError(Store, (error.response.data) ? error.response.data : error);
        })
            .then(function () {
            // always executed
        });
    });
};
export var RequestClearCDMContract = function (host, port, tradeIdList) {
    console.log('http://' + host + ':' + port + '/api/memberApi/clearCDMContract');
    tradeIdList.forEach(function (tid) {
        var data = { contractId: tid, contractIdScheme: 'http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/' };
        axios.post('http://' + host + ':' + port + '/api/memberApi/clearCDMContract', data)
            .then(function (response) {
            console.log(response);
            NewLogEntry(Store, 'Clear Live Trade(s). ' + response.data, false, 10);
        })
            .catch(function (error) {
            // handle error
            console.error(error.response.data);
            NewError(Store, (error.response.data) ? error.response.data : error);
        })
            .then(function () {
            // always executed
        });
    });
};
export var RequestResetTrades = function (host, port, resetDate) {
    axios.post('http://' + host + ':' + port + '/api/memberApi/fixCDMContracts', resetDate)
        .then(function (response) {
        var contracts = "";
        console.log(response.data.forEach(function (x) { return contracts = contracts + ' ' + x.contractId; }));
        NewLogEntry(Store, 'Reset Trade(s): ' + contracts + ' . Date : ' + resetDate, false, 10);
        HistoryState.push("/trades/");
    })
        .catch(function (error) {
        // handle error
        console.error(error.response.data);
        NewError(Store, (error.response.data) ? error.response.data : error);
    })
        .then(function () {
        // always executed
    });
};
export var GetPayments = function (host, port, tradeId) {
    console.log("http://" + host + ":" + port + "/api/memberApi/CDMResets?contractId=" + tradeId + "&contractIdScheme=http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/");
    axios.get("http://" + host + ":" + port + "/api/memberApi/CDMResets?contractId=" + tradeId + "&contractIdScheme=http://www.fpml.org/coding-scheme/external/unique-transaction-identifier/")
        .then(function (response) {
        console.log(response.data);
        response.data.map(function (cfe) { return (__assign({}, cfe, { contractId: tradeId })); }).forEach(function (cfe) { return Store.dispatch(PaymentReceivedAction(cfe)); });
    })
        .catch(function (error) {
        // handle error
        console.error(error.response.data);
        NewError(Store, (error.response.data) ? error.response.data : error);
    })
        .then(function () {
        // always executed
    });
};
//# sourceMappingURL=rpc.js.map